@@ -23,8 +23,7 @@
 **
 ****************************************************************************/
 
-#ifndef NODEINSTANCESERVERINTERFACE_H
-#define NODEINSTANCESERVERINTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -34,6 +33,7 @@ class PropertyAbstractContainer;
 class PropertyBindingContainer;
 class PropertyValueContainer;
 
+class Update3dViewStateCommand;
 class ChangeFileUrlCommand;
 class ChangeValuesCommand;
 class ChangeBindingsCommand;
@@ -50,6 +50,9 @@ class CompleteComponentCommand;
 class ChangeNodeSourceCommand;
 class TokenCommand;
 class RemoveSharedMemoryCommand;
+class ChangeSelectionCommand;
+class InputEventCommand;
+class View3DActionCommand;
 
 class NodeInstanceServerInterface : public QObject
 {
@@ -60,12 +63,13 @@ public:
         TestModus // No preview images and synchronized
     };
 
-    explicit NodeInstanceServerInterface(QObject *parent = 0);
+    explicit NodeInstanceServerInterface(QObject *parent = nullptr);
 
     virtual void createInstances(const CreateInstancesCommand &command) = 0;
     virtual void changeFileUrl(const ChangeFileUrlCommand &command) = 0;
     virtual void createScene(const CreateSceneCommand &command) = 0;
     virtual void clearScene(const ClearSceneCommand &command) = 0;
+    virtual void update3DViewState(const Update3dViewStateCommand &command) = 0;
     virtual void removeInstances(const RemoveInstancesCommand &command) = 0;
     virtual void removeProperties(const RemovePropertiesCommand &command) = 0;
     virtual void changePropertyBindings(const ChangeBindingsCommand &command) = 0;
@@ -78,9 +82,14 @@ public:
     virtual void changeNodeSource(const ChangeNodeSourceCommand &command) = 0;
     virtual void token(const TokenCommand &command) = 0;
     virtual void removeSharedMemory(const RemoveSharedMemoryCommand &command) = 0;
+    virtual void changeSelection(const ChangeSelectionCommand &command) = 0;
+    virtual void inputEvent(const InputEventCommand &command) = 0;
+    virtual void view3DAction(const View3DActionCommand &command) = 0;
+
+    virtual void benchmark(const QString &)
+    {}
 
     static void registerCommands();
 };
 
 }
-#endif // NODEINSTANCESERVERINTERFACE_H
