@@ -137,7 +137,7 @@ void ObjectNodeInstance::initialize(const ObjectNodeInstance::Pointer &objectNod
 void ObjectNodeInstance::setId(const QString &id)
 {
     if (!m_id.isEmpty() && context()) {
-        context()->engine()->rootContext()->setContextProperty(m_id, 0);
+        context()->engine()->rootContext()->setContextProperty(m_id, nullptr);
     }
 
     if (!id.isEmpty() && context()) {
@@ -324,7 +324,7 @@ void ObjectNodeInstance::removeFromOldProperty(QObject *object, QObject *oldPare
     }
 
     if (object && object->parent())
-        object->setParent(0);
+        object->setParent(nullptr);
 }
 
 void ObjectNodeInstance::addToNewProperty(QObject *object, QObject *newParent, const PropertyName &newParentProperty)
@@ -392,6 +392,15 @@ PropertyNameList ObjectNodeInstance::ignoredProperties() const
     return PropertyNameList();
 }
 
+void ObjectNodeInstance::setHideInEditor(bool)
+{
+}
+
+void ObjectNodeInstance::setModifiedFlag(bool b)
+{
+    m_isModified = b;
+}
+
 QVariant ObjectNodeInstance::convertEnumToValue(const QVariant &value, const PropertyName &name)
 {
     Q_ASSERT(value.canConvert<Enumeration>());
@@ -416,6 +425,9 @@ void ObjectNodeInstance::setPropertyVariant(const PropertyName &name, const QVar
     if (ignoredProperties().contains(name))
         return;
 
+    if (m_isModified)
+        return;
+
     QQmlProperty property(object(), QString::fromUtf8(name), context());
 
     if (!property.isValid())
@@ -559,11 +571,30 @@ QVariant ObjectNodeInstance::property(const PropertyName &name) const
     return property.read();
 }
 
+void ObjectNodeInstance::ensureVector3DDotProperties(PropertyNameList &list) const
+{
+    const PropertyNameList properties = { "rotation", "scale", "pivot" };
+    for (const auto &property : properties) {
+        if (list.contains(property) && instanceType(property) == "QVector3D") {
+            const PropertyNameList dotProperties = { "x", "y", "z" };
+            for (const auto &dotProperty : dotProperties) {
+                const PropertyName dotPropertyName = property + "." + dotProperty;
+                if (!list.contains(dotPropertyName))
+                    list.append(dotPropertyName);
+            }
+        }
+    }
+}
+
 PropertyNameList ObjectNodeInstance::propertyNames() const
 {
+    PropertyNameList list;
     if (isValid())
-        return QmlPrivateGate::allPropertyNames(object());
-    return PropertyNameList();
+        list = QmlPrivateGate::allPropertyNames(object());
+
+    ensureVector3DDotProperties(list);
+
+    return list;
 }
 
 QString ObjectNodeInstance::instanceType(const PropertyName &name) const
@@ -622,7 +653,6 @@ QObject *ObjectNodeInstance::createPrimitive(const QString &typeName, int majorN
             || typeName == "QtQuick.Controls/Drawer"
             || typeName == "QtQuick.Controls/Dialog"
             || typeName == "QtQuick.Controls/Menu"
-            || typeName == "QtQuick.Controls/Pane"
             || typeName == "QtQuick.Controls/ToolTip")
         polishTypeName = "QtQuick/Item";
 
@@ -633,7 +663,7 @@ QObject *ObjectNodeInstance::createPrimitive(const QString &typeName, int majorN
 
     if (mockHash.contains(typeName))
         object = QmlPrivateGate::createComponent(mockHash.value(typeName), context);
-    else
+    else if (majorNumber != -1 && minorNumber != -1)
         object = QmlPrivateGate::createPrimitive(polishTypeName, majorNumber, minorNumber, context);
 
     /* Let's try to create the primitive from source, since with incomplete meta info this might be a pure
@@ -649,14 +679,14 @@ QObject *ObjectNodeInstance::createPrimitive(const QString &typeName, int majorN
 QObject *ObjectNodeInstance::createPrimitiveFromSource(const QString &typeName, int majorNumber, int minorNumber, QQmlContext *context)
 {
     if (typeName.isEmpty())
-        return 0;
+        return nullptr;
 
     QStringList parts = typeName.split("/");
     const QString unqualifiedTypeName = parts.last();
     parts.removeLast();
 
     if (parts.isEmpty())
-        return 0;
+        return nullptr;
 
     QString importString = parts.join(".") + " " + QString::number(majorNumber) + "." + QString::number(minorNumber);
     if (importString == "QtQuick 1.0") /* Workaround for implicit QQml import */
@@ -723,10 +753,14 @@ QObject *ObjectNodeInstance::createComponent(const QString &componentPath, QQmlC
     Q_UNUSED(disableComponentComplete)
 
     QQmlComponent component(context->engine(), fixComponentPathForIncompatibleQt(componentPath));
-    QObject *object = component.beginCreate(context);
 
-    QmlPrivateGate::tweakObjects(object);
-    component.completeCreate();
+    QObject *object = nullptr;
+    if (!component.isError()) {
+        object = component.beginCreate(context);
+        QmlPrivateGate::tweakObjects(object);
+        component.completeCreate();
+        QQmlEngine::setObjectOwnership(object, QQmlEngine::CppOwnership);
+    }
 
     if (component.isError()) {
         qDebug() << componentPath;
@@ -734,8 +768,6 @@ QObject *ObjectNodeInstance::createComponent(const QString &componentPath, QQmlC
             qWarning() << error;
     }
 
-    QQmlEngine::setObjectOwnership(object, QQmlEngine::CppOwnership);
-
     return object;
 }
 
@@ -772,12 +804,12 @@ QObject *ObjectNodeInstance::object() const
 {
         if (!m_object.isNull() && !QmlPrivateGate::objectWasDeleted(m_object.data()))
             return m_object.data();
-        return 0;
+        return nullptr;
 }
 
 QQuickItem *ObjectNodeInstance::contentItem() const
 {
-    return 0;
+    return nullptr;
 }
 
 bool ObjectNodeInstance::hasContent() const
@@ -819,7 +851,7 @@ QQmlContext *ObjectNodeInstance::context() const
         return nodeInstanceServer()->context();
 
     qWarning() << "Error: No NodeInstanceServer";
-    return 0;
+    return nullptr;
 }
 
 QQmlEngine *ObjectNodeInstance::engine() const
@@ -839,6 +871,11 @@ void ObjectNodeInstance::deactivateState()
 {
 }
 
+QStringList ObjectNodeInstance::allStates() const
+{
+    return {};
+}
+
 void ObjectNodeInstance::populateResetHashes()
 {
     QmlPrivateGate::registerCustomData(object());
@@ -867,7 +904,7 @@ QImage ObjectNodeInstance::renderPreviewImage(const QSize & /*previewImageSize*/
 QObject *ObjectNodeInstance::parent() const
 {
     if (!object())
-        return 0;
+        return nullptr;
 
     return object()->parent();
 }
